@@ -230,3 +230,47 @@ def deconvolve(count_matrix, exp_design, cores, gb_ref, filter_thr, global_filte
     print("Inferring most likely locations and writing location summary!")
     experiment.deconvolve()
     print("Done!")
+
+@click.command()
+@click.argument("count_matrix", type=str)
+@click.argument("exp_design", type=str)
+@click.option("--cores", '-c',
+              metavar='<str>',
+              type=int,
+              default=1,
+              help='Number of cpu cores to use')
+@click.option("--gb_ref", '-gb',
+              metavar='<str>',
+              type=str,
+              help='Path to genbank reference file')
+@click.option("--filter_thr", '-thr',
+              metavar='<int>',
+              type=float,
+              default=0.05,
+              help='Count filter threshold')
+@click.option("--global_filter_thr", '-g_thr',
+              metavar='<int>',
+              type=float,
+              default=5,
+              help='Count filter threshold')
+def deconvolve_validation(count_matrix, exp_design, cores, gb_ref, filter_thr, global_filter_thr) :
+    """ 
+    Run pysudoku to infer the most likely locations for each mutant from a 
+    precomputed count matrix.
+    COUNT_MATRIX should be a path to a precomputed count matrix and EXP_DESIGN 
+    a csv file with columns Filename, Poolname and 
+    Pooldimension indicating which files belong to which pool and pooling 
+    dimension.
+    """
+    if count_matrix == None:
+        raise ValueError("Please provide path to count matrix!")
+   
+    experiment = LibraryExperiment(cores,map_quality =None,seq_quality=None,gb_ref=gb_ref, bowtie_ref=None, 
+                                    tn_seq=None, tn_mismatches=None, input_dir=None, exp_design=exp_design,
+                                    use_barcodes=True, bar_upstream=None, bar_downstream=None, filter_thr=filter_thr, 
+                                    global_filter_thr=global_filter_thr, min_counts=5)
+    c = pd.read_csv(count_matrix)
+    experiment.count_mat = c
+    print("Inferring most likely locations and writing location summary!")
+    experiment.deconvolve_validation()
+    print("Done!")
\ No newline at end of file
